from __future__ import annotations

from typing import TYPE_CHECKING

from bozodown.bozodown import Bozodown

if TYPE_CHECKING:
    from picture import Picture

class Photodown(Bozodown):

    def __init__(self):
        super().__init__()
        self._specific_case_namespaces.update({"photohub": self._photohub_render})
        image_converter = self._converters.get("image")
        image_converter.update({"code": "photohub:image"})
        self._converters.update({"pictures": {"from_prefix": "+++++","from_suffix": "+++++","code": "photohub:pictures",}})
        self._bulk: list[Picture] = []

    def add_bulk(self, bulk: list[Picture]):
        self._bulk = bulk.copy()

    def _render_image(self, url: str) -> str:
        if (url.startswith("./")):
            for picture in self._bulk:
                if url == "." + picture.get_large().get_url()[:-4]:
                    return f"""<a href={picture.get_page().html.get_url()}><img src='{picture.get_small().get_url()}'></a>"""
        return f"<img src='{url}'>"

    def _render_pictures(self, config: dict[str, str | int], to_parse: str):
        segments: list[str] = to_parse.split("--")
        content: str = ""
        for segment in segments:
            content += f"<div class='pictures-item'>{self.render(segment)}</div>"
        return f"<div class='pictures-menu'>{content}</div>"

    def _photohub_render(self, id: str, text: str) -> str:
        if (id == "image"):
            picture_url = f"{text[2:-1]}"
            return self._render_image(picture_url)
        if (id == "pictures"):
            config, style, to_parse = text[5:-5].split("---")
            style = style.replace("\n", "")
            config = {
                k: v for line in config.strip().splitlines()
                if ": " in line
                for k, v in [line.split(": ", 1)]
            }
            content: str = self._render_pictures(config, to_parse)
            return f"<div style='{style}'>{content}</div>"
                
